@@ -1,6 +1,5 @@
-plot_clone=function (plot) 
-{
+plot_clone <- function(plot) {
   p <- plot
   p$scales <- plot$scales$clone()
   p
-}
\ No newline at end of file
+}
