@@ -4,8 +4,8 @@
 #' @return list
 #' @keywords internal
 rmNullObs <- function(x) {
-  if(!(is.function(x))) {
-    x = x[!(sapply(x, is.NullOb))]
+  if (!(is.function(x))) {
+    x <- x[!(sapply(x, is.NullOb))]
     lapply(x, function(x) if (is.list(x)) rmNullObs(x) else x)
   }
-}
\ No newline at end of file
+}
